@@ -4,6 +4,8 @@
 
 import argparse
 from subprocess import Popen, PIPE
+import os
+from sys import platform as plat
 
 def insdat():
     # Input data, var, and pass for encrypting.
@@ -27,8 +29,11 @@ def insdat():
             return self.e1
     
         def apply(self):
-            if self.e1.get() and self.e2.get() and self.e3.get():
-                self.result = (self.e1.get(), self.e2.get(), self.e3.get())
+            if self.e1.get() and self.e3.get():
+                if self.e2.get():
+                    self.result = (self.e1.get(), self.e2.get(), self.e3.get())
+                else:
+                    self.result = (self.e1.get(), self.e3.get())
             else:
                 self.result = None
                 
@@ -59,8 +64,41 @@ def pssd():
     root.destroy()
     if d.result:
         return d.result    
+
+def ckshenv():
+    # Checking for MacOS terminal shell and it's files 
+
+    sh = os.environ.get('SHELL', None)
+    if sh and not plat.startswith('win'):
+        if sh.rpartition('/')[2].startswith('z'):
+            return {
+                'zsh': [i for i in os.listdir(os.path.expanduser('~')) if i.startswith('.z')]
+            }
+        else:
+            return {
+                'bash': [i for i in os.listdir(os.path.expanduser('~')) if i.startswith('.b')]
+            }
+    else:
+        return sh
+
+
+def varenv(val: str, var: str):
+    # Writing environment variable to MacOS
     
-def cmsk(data: str, varn: str, base: str):
+    wr = f'{var}="{val}"'
+    ck = ckshenv()
+    if ck:
+        wrto = ('zprofile'
+                if tuple(ck.keys())[0] == 'zsh' 
+                else 'bash_profile'
+               )
+        os.system(f'echo  >> {os.path.expanduser("~")}/.{wrto}')
+        os.system(f'echo {wr} >> {os.path.expanduser("~")}/.{wrto}')
+        os.system(f'echo export {var} >> {os.path.expanduser("~")}/.{wrto}')
+    else:
+        print('Unimplemented!')
+
+def cmsk(data: str, base: str, varn: str = None):
     # WARNING:
     # Do not set variable that already exist and important.
     
@@ -73,17 +111,33 @@ def cmsk(data: str, varn: str, base: str):
     except:
         print('Error Occured!')
     else:
-        pnam = f'setx {varn} {nlt.decode()}'
-        with Popen(pnam, stdout = PIPE, bufsize = 1, universal_newlines = True, text = True) as p:
-            for line in p.stdout:
-                copline = line
-                print(copline, end='')
-        if 'SUCCESS:' in copline:
-            print(f'var: {varn}')
-            print('Please restart the console!')
+        if varn:
+            if plat.startswith('win'):
+                pnam = f'setx {varn} {nlt.decode()}'
+                copline = None
+                with Popen(
+                    pnam, 
+                    stdout = PIPE, 
+                    bufsize = 1, 
+                    universal_newlines = True, 
+                    text = True
+                    ) as p:
+                    for line in p.stdout:
+                        copline = line
+                        print(copline, end='')
+                if 'SUCCESS:' in copline:
+                    print(f'var: {varn}')
+                    print('Please restart the console!')
+                else:
+                    print(f'Variable {varn} not created yet!')
+                del copline
+            else:
+                varenv(nlt.decode(), varn)
         else:
-            print(f'Variable {varn} not created yet!')
-        del lb, base, nlt, copline, varn, p
+            return nlt.decode()
+    finally:
+        del lb, nlt, base, data, varn
+            
     
 def reading(data: str, base: str):
     # reading var that created
@@ -123,7 +177,7 @@ def main():
     if args.create:
         a = insdat()
         if a:
-            cmsk(a[0], a[1], a[2])
+            cmsk(a[0], a[2], a[1])
         else:
             print('Please fill all fields!')
     elif args.read:
@@ -134,4 +188,4 @@ def main():
             print('Please fill field!')
 
 if __name__ == "__main__":
-    main()   
\ No newline at end of file
+    main()
\ No newline at end of file
